MALLOCX_ARENA

Function MALLOCX_ARENA 

pub const fn MALLOCX_ARENA(a: usize) -> i32
Available on crate feature cli only.
Use the arena specified by the index a.

This option has no effect for regions that were allocated via an arena other than the one specified.

Safety

This function does not validate that a specifies an arena index in the valid range.