Function MALLOCX_LG_ALIGN
pub const fn MALLOCX_LG_ALIGN(la: usize) -> i32Available on crate feature
cli only.Expand description
Align the memory allocation to start at an address that is a
multiple of 1 << la.
Safety
It does not validate that la is within the valid range.