pub trait ExtendedCommand {
// Required method
fn execute(self, runner: CliRunner) -> Result<(), Report>;
}Available on crate feature
cli only.Expand description
A trait for extension subcommands that can be added to the CLI.
Consumers implement this trait for their custom subcommands to define how they should be executed.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".