pub fn install()Available on Unix and crate feature
cli and (GNU or macOS) only.Expand description
Installs a SIGSEGV handler.
When SIGSEGV is delivered to the process, print a stack trace and then exit.
pub fn install()cli and (GNU or macOS) only.Installs a SIGSEGV handler.
When SIGSEGV is delivered to the process, print a stack trace and then exit.