Trait JournalExt
pub trait JournalExt: JournalTr<State = HashMap<Address, Account, FbBuildHasher<20>>> {
// Required method
fn journal(&self) -> &[JournalEntry];
}Available on crate feature
evm only.Expand description
Extends the journal with additional methods that are used by the inspector.
Required Methods
fn journal(&self) -> &[JournalEntry]
fn journal(&self) -> &[JournalEntry]
Get the journal entries that are created from last checkpoint. new checkpoint is created when sub call is made.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".