Function init_keccak_cache
pub fn init_keccak_cache(entries: usize) -> boolAvailable on crate feature
evm only.Expand description
Initializes the process-global keccak cache with entries buckets.
Returns true if this call initialized the cache, and false if the cache was already
initialized by an earlier call or by the first cached hash computation. If this is never called,
the cache is initialized lazily with the default size on first use.
Panics
Panics if entries is not a power of two or is less than 4.