Function logs_bloom
pub fn logs_bloom<'a>(logs: impl IntoIterator<Item = &'a Log>) -> BloomAvailable on crate feature
evm only.Expand description
Compute the logs bloom filter for the given logs.
pub fn logs_bloom<'a>(logs: impl IntoIterator<Item = &'a Log>) -> Bloomevm only.Compute the logs bloom filter for the given logs.