Function nbytes
pub const fn nbytes(bits: usize) -> usizeAvailable on crate feature
evm only.Expand description
Number of bytes required to represent the given number of bits.
This needs to be public because it is used in the Uint type,
specifically in the to_be_bytes() and related
functions.