DBErrorMarker

Trait DBErrorMarker 

pub trait DBErrorMarker:
    Error
    + Send
    + Sync
    + 'static {
    // Provided method
    fn is_fatal(&self) -> bool { ... }
}
Available on crate feature evm only.
Database error marker is needed to implement From conversion for Error type.

Provided Methods

fn is_fatal(&self) -> bool

Returns true if the error is fatal and execution cannot recover from it.

Defaults to true. Implementors can override this to signal recoverable errors.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types



impl DBErrorMarker for Infallible

Implement marker for ().

Implementors



impl DBErrorMarker for reth_ethereum::evm::primitives::ErasedError



impl DBErrorMarker for reth_ethereum::evm::revm::db::ErasedError

Source

impl DBErrorMarker for ProviderError



impl<ERROR> DBErrorMarker for EvmDatabaseError<ERROR>
where ERROR: Error + Send + Sync + 'static,