pub trait SyncStateProvider: Send + Sync {
// Required methods
fn is_syncing(&self) -> bool;
fn is_initially_syncing(&self) -> bool;
}Available on crate feature
network only.Expand description
A type that provides information about whether the node is currently syncing and the network is currently serving syncing related requests.
Required Methods
Sourcefn is_syncing(&self) -> bool
fn is_syncing(&self) -> bool
Returns true if the network is undergoing sync.
Sourcefn is_initially_syncing(&self) -> bool
fn is_initially_syncing(&self) -> bool
Returns true if the network is undergoing an initial (pipeline) sync.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".