pub fn buffer_hash_to_tx_fetcher(
tx_fetcher: &mut TransactionFetcher,
hash: FixedBytes<32>,
peer_id: FixedBytes<64>,
tx_encoded_length: Option<usize>,
)Available on crate feature
network and (crate features test-utils) only.Expand description
Announces a hash to the tx fetcher on behalf of the given peer, without sending a request.