pub struct DefaultDevArgs {
pub dev: bool,
pub block_max_transactions: Option<usize>,
pub block_time: Option<Duration>,
pub finality_depth: NonZero<usize>,
pub payload_wait_time: Option<Duration>,
pub dev_mnemonic: String,
}node-api only.Expand description
Default values for dev testnet CLI arguments that can be customized.
Global defaults can be set via DefaultDevArgs::try_init.
Fields
dev: boolDefault for --dev.
block_max_transactions: Option<usize>Default maximum number of transactions to mine per block.
block_time: Option<Duration>Default interval between blocks.
finality_depth: NonZero<usize>Default number of confirmations required before finalization.
payload_wait_time: Option<Duration>Default time to wait before resolving a payload.
dev_mnemonic: StringDefault mnemonic used to derive dev accounts.
Implementations
Sourceimpl DefaultDevArgs
impl DefaultDevArgs
Sourcepub fn try_init(self) -> Result<(), DefaultDevArgs>
pub fn try_init(self) -> Result<(), DefaultDevArgs>
Initialize the global dev testnet defaults with this configuration.
Sourcepub fn get_global() -> &'static DefaultDevArgs
pub fn get_global() -> &'static DefaultDevArgs
Get a reference to the global dev testnet defaults.
Sourcepub const fn with_dev(self, dev: bool) -> DefaultDevArgs
pub const fn with_dev(self, dev: bool) -> DefaultDevArgs
Set whether dev mode is enabled by default.
Sourcepub const fn with_block_max_transactions(
self,
count: Option<usize>,
) -> DefaultDevArgs
pub const fn with_block_max_transactions( self, count: Option<usize>, ) -> DefaultDevArgs
Set the default maximum number of transactions to mine per block.
Sourcepub const fn with_block_time(
self,
block_time: Option<Duration>,
) -> DefaultDevArgs
pub const fn with_block_time( self, block_time: Option<Duration>, ) -> DefaultDevArgs
Set the default interval between blocks.
Sourcepub const fn with_finality_depth(
self,
finality_depth: NonZero<usize>,
) -> DefaultDevArgs
pub const fn with_finality_depth( self, finality_depth: NonZero<usize>, ) -> DefaultDevArgs
Set the default number of confirmations required before finalization.
Sourcepub const fn with_payload_wait_time(
self,
payload_wait_time: Option<Duration>,
) -> DefaultDevArgs
pub const fn with_payload_wait_time( self, payload_wait_time: Option<Duration>, ) -> DefaultDevArgs
Set the default time to wait before resolving a payload.
Sourcepub fn with_dev_mnemonic(self, dev_mnemonic: String) -> DefaultDevArgs
pub fn with_dev_mnemonic(self, dev_mnemonic: String) -> DefaultDevArgs
Set the default mnemonic used to derive dev accounts.