Trait SignableTxRequest
pub trait SignableTxRequest<T>:
Send
+ Sync
+ 'static {
// Required method
fn try_build_and_sign(
self,
signer: impl TxSigner<Signature> + Send,
) -> impl Future<Output = Result<T, SignTxRequestError>> + Send;
}Available on crate feature
node-api only.Expand description
An abstraction over transaction requests that can be signed.
Required Methods
fn try_build_and_sign(
self,
signer: impl TxSigner<Signature> + Send,
) -> impl Future<Output = Result<T, SignTxRequestError>> + Send
fn try_build_and_sign( self, signer: impl TxSigner<Signature> + Send, ) -> impl Future<Output = Result<T, SignTxRequestError>> + Send
Attempts to build a transaction request and sign it with the given signer.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".