pub type BuiltPayloadCancun = ExecutionPayloadEnvelopeV3;Available on crate features
node-api and node only.Expand description
Engine API v2 REST-SSZ payload-build response for Cancun.
This is wire-compatible with the legacy engine_getPayloadV3 response envelope.
Aliased Type
pub struct BuiltPayloadCancun {
pub execution_payload: ExecutionPayloadV3,
pub block_value: Uint<256, 4>,
pub blobs_bundle: BlobsBundleV1,
pub should_override_builder: bool,
}Fields
execution_payload: ExecutionPayloadV3Execution payload V3
block_value: Uint<256, 4>The expected value to be received by the feeRecipient in wei
blobs_bundle: BlobsBundleV1The blobs, commitments, and proofs associated with the executed payload.
should_override_builder: boolIntroduced in V3, this represents a suggestion from the execution layer if the payload should be used instead of an externally provided one.
Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 712 bytes