pub type ExecutionPayloadAmsterdam = ExecutionPayloadV4;Available on crate features
node-api and node only.Expand description
Amsterdam execution payload.
Aliased Type
pub struct ExecutionPayloadAmsterdam {
pub payload_inner: ExecutionPayloadV3,
pub block_access_list: Bytes,
pub slot_number: u64,
}Fields
payload_inner: ExecutionPayloadV3Inner V3 payload
block_access_list: BytesRLP-encoded block access list as defined in EIP-7928.
slot_number: u64The slot number corresponding to this block, calculated in the consensus layer.
Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 640 bytes