maybe_run_jit_helper

Function maybe_run_jit_helper 

pub fn maybe_run_jit_helper() -> Result<ControlFlow<()>, Report>
Available on crate features node-api and node only.
Runs the out-of-process JIT helper if this process was launched as one.

Returns ControlFlow::Break after the helper request has been handled and the caller should exit immediately. Normal application startup should continue on ControlFlow::Continue.