build_evm_config

Function build_evm_config 

pub fn build_evm_config<C>(
    chain_spec: Arc<C>,
    jit: &JitArgs,
    dump_dir: Option<PathBuf>,
) -> Result<(EthEvmConfig<C, RethEvmFactory>, Option<Arc<RevmcMetrics>>), Report>
Available on crate features jit and node-api and node only.
Builds an EthEvmConfig with revmc JIT from CLI JitArgs.

This is the shared setup used by both EthereumExecutorBuilder and reth re-execute.

Returns the evm config and metrics recorder if JIT starts enabled.