ColumnSelectorOne

Trait ColumnSelectorOne 

pub trait ColumnSelectorOne {
    type FIRST: Decompress;

    const MASK: usize;
}
Available on crate feature provider only.
Trait for specifying a mask to select one column value.

Required Associated Constants

const MASK: usize

Mask to obtain desired values, should correspond to the order of columns in a static_file.

Required Associated Types

type FIRST: Decompress

First desired column value

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors