pub fn range_size_hint(range: &impl RangeBounds<u64>) -> Option<usize>Available on crate features
db-api and provider only.Expand description
Returns the length of the range if the range has a bounded end.
pub fn range_size_hint(range: &impl RangeBounds<u64>) -> Option<usize>db-api and provider only.Returns the length of the range if the range has a bounded end.