pub struct BalStoreHandle { /* private fields */ }provider only.Expand description
Clone-friendly façade around a BAL store implementation.
Implementations
Sourceimpl BalStoreHandle
impl BalStoreHandle
Sourcepub fn new(inner: impl BalStore) -> BalStoreHandle
pub fn new(inner: impl BalStore) -> BalStoreHandle
Creates a new BalStoreHandle from the given implementation.
Sourcepub fn noop() -> BalStoreHandle
pub fn noop() -> BalStoreHandle
Creates a BalStoreHandle backed by NoopBalStore.
Sourcepub fn insert(
&self,
num_hash: NumHash,
bal: Sealed<Bytes>,
) -> Result<(), ProviderError>
pub fn insert( &self, num_hash: NumHash, bal: Sealed<Bytes>, ) -> Result<(), ProviderError>
Insert the BAL for the given block.
Sourcepub fn insert_many(
&self,
entries: Vec<(NumHash, Sealed<Bytes>)>,
) -> Result<(), ProviderError>
pub fn insert_many( &self, entries: Vec<(NumHash, Sealed<Bytes>)>, ) -> Result<(), ProviderError>
Insert multiple BALs.
Sourcepub fn flush(&self) -> Result<(), ProviderError>
pub fn flush(&self) -> Result<(), ProviderError>
Flushes any pending BALs to the backing store.
Sourcepub fn prune(&self, tip: u64) -> Result<usize, ProviderError>
pub fn prune(&self, tip: u64) -> Result<usize, ProviderError>
Prunes expired BALs according to the store’s retention policy and the given chain tip.
Sourcepub fn get_by_hashes(
&self,
block_hashes: &[FixedBytes<32>],
) -> Result<Vec<Option<Bytes>>, ProviderError>
pub fn get_by_hashes( &self, block_hashes: &[FixedBytes<32>], ) -> Result<Vec<Option<Bytes>>, ProviderError>
Fetch BALs for the given block hashes.
Sourcepub fn get_by_hash(
&self,
block_hash: FixedBytes<32>,
) -> Result<Option<Bytes>, ProviderError>
pub fn get_by_hash( &self, block_hash: FixedBytes<32>, ) -> Result<Option<Bytes>, ProviderError>
Fetches the BAL for the given block hash.
Sourcepub fn get_decoded_by_hash(
&self,
block_hash: FixedBytes<32>,
) -> Result<Option<DecodedBal>, ProviderError>
pub fn get_decoded_by_hash( &self, block_hash: FixedBytes<32>, ) -> Result<Option<DecodedBal>, ProviderError>
Fetches and decodes the BAL for the given block hash.
Sourcepub fn revm_bal_by_hash(
&self,
block_hash: FixedBytes<32>,
) -> Result<Option<DecodedBal<Bal>>, ProviderError>
pub fn revm_bal_by_hash( &self, block_hash: FixedBytes<32>, ) -> Result<Option<DecodedBal<Bal>>, ProviderError>
Fetches the BAL for the given block hash in revm representation.
Sourcepub fn get_by_hashes_with_limit(
&self,
block_hashes: &[FixedBytes<32>],
limit: GetBlockAccessListLimit,
) -> Result<Vec<Option<Bytes>>, ProviderError>
pub fn get_by_hashes_with_limit( &self, block_hashes: &[FixedBytes<32>], limit: GetBlockAccessListLimit, ) -> Result<Vec<Option<Bytes>>, ProviderError>
Fetch BAL response entries for the given block hashes, stopping after the soft limit is exceeded.
Sourcepub fn append_by_hashes_with_limit(
&self,
block_hashes: &[FixedBytes<32>],
limit: GetBlockAccessListLimit,
out: &mut Vec<Option<Bytes>>,
) -> Result<(), ProviderError>
pub fn append_by_hashes_with_limit( &self, block_hashes: &[FixedBytes<32>], limit: GetBlockAccessListLimit, out: &mut Vec<Option<Bytes>>, ) -> Result<(), ProviderError>
Extends the given vector with BAL response entries for the given hashes.
Sourcepub fn get_by_range(
&self,
start: u64,
count: u64,
) -> Result<Vec<Bytes>, ProviderError>
pub fn get_by_range( &self, start: u64, count: u64, ) -> Result<Vec<Bytes>, ProviderError>
Fetch BALs for the requested range.
Sourcepub fn bal_stream(&self) -> EventStream<BalNotification>
Available on crate feature std only.
pub fn bal_stream(&self) -> EventStream<BalNotification>
std only.Returns a stream of BAL insert notifications.