pub type DecodedRevmBal = DecodedBal<Arc<Bal>>;Available on crate feature
provider only.Expand description
A decoded EIP-7928 block access list in the representation revm consumes, paired with the raw RLP payload it was decoded from.
Produced once during block validation and shared with consumers such as the RPC state cache, so the RLP payload does not have to be decoded and converted a second time.
Aliased Type
pub struct DecodedRevmBal { /* private fields */ }Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 80 bytes