pub trait EthCallBundleApiClient: ClientT {
// Provided method
fn call_bundle(
&self,
request: EthCallBundle,
) -> impl Future<Output = Result<EthCallBundleResponse, Error>> + Send { ... }
}Available on crate feature
rpc only.Expand description
Client implementation for the EthCallBundleApi RPC API.
Provided Methods
Sourcefn call_bundle(
&self,
request: EthCallBundle,
) -> impl Future<Output = Result<EthCallBundleResponse, Error>> + Send
fn call_bundle( &self, request: EthCallBundle, ) -> impl Future<Output = Result<EthCallBundleResponse, Error>> + Send
eth_callBundle can be used to simulate a bundle against a specific block number,
including simulating a bundle at the top of the next block.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".