pub trait MinerApiClient: ClientT {
// Provided methods
fn set_extra(
&self,
record: Bytes,
) -> impl Future<Output = Result<bool, Error>> + Send { ... }
fn set_gas_price(
&self,
gas_price: Uint<128, 2>,
) -> impl Future<Output = Result<bool, Error>> + Send { ... }
fn set_gas_limit(
&self,
gas_limit: Uint<128, 2>,
) -> impl Future<Output = Result<bool, Error>> + Send { ... }
}Available on crate feature
rpc only.Expand description
Client implementation for the MinerApi RPC API.
Provided Methods
Sourcefn set_extra(
&self,
record: Bytes,
) -> impl Future<Output = Result<bool, Error>> + Send
fn set_extra( &self, record: Bytes, ) -> impl Future<Output = Result<bool, Error>> + Send
Sets the extra data string that is included when this miner mines a block.
Returns an error if the extra data is too long.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".