StateOverride

Type Alias StateOverride 

pub type StateOverride = HashMap<Address, AccountOverride, FbBuildHasher<20>>;
Available on crate feature rpc only.
Account overrides keyed by the address whose state should be changed for the call.

Aliased Type

pub struct StateOverride { /* private fields */ }

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 40 bytes