pub trait HashedPostStateProvider {
// Required method
fn hashed_post_state(
&self,
bundle_state: &BundleState,
) -> Result<HashedPostState, ProviderError>;
}Available on crate feature
storage-api only.Expand description
Trait that provides the hashed state from various sources.
Required Methods
Sourcefn hashed_post_state(
&self,
bundle_state: &BundleState,
) -> Result<HashedPostState, ProviderError>
fn hashed_post_state( &self, bundle_state: &BundleState, ) -> Result<HashedPostState, ProviderError>
Returns the HashedPostState of the provided BundleState, materializing zero-valued
updates for parent storage of accounts that were destroyed but remain in the post-state.
Providers backed by an exact parent-state view also materialize terminally destroyed accounts with explicit zero-valued storage updates.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".