StageCheckpointReader

Trait StageCheckpointReader 

pub trait StageCheckpointReader: Send {
    // Required methods
    fn get_stage_checkpoint(
        &self,
        id: StageId,
    ) -> Result<Option<StageCheckpoint>, ProviderError>;
    fn get_stage_checkpoint_progress(
        &self,
        id: StageId,
    ) -> Result<Option<Vec<u8>>, ProviderError>;
    fn get_all_checkpoints(
        &self,
    ) -> Result<Vec<(String, StageCheckpoint)>, ProviderError>;
}
Available on crate feature storage-api only.
The trait for fetching stage checkpoint related data.

Required Methods

fn get_stage_checkpoint( &self, id: StageId, ) -> Result<Option<StageCheckpoint>, ProviderError>

Fetch the checkpoint for the given stage.

fn get_stage_checkpoint_progress( &self, id: StageId, ) -> Result<Option<Vec<u8>>, ProviderError>

Get stage checkpoint progress.

fn get_all_checkpoints( &self, ) -> Result<Vec<(String, StageCheckpoint)>, ProviderError>

Reads all stage checkpoints and returns a list with the name of the stage and the checkpoint data.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, T> StageCheckpointReader for &'a T

Source

impl<T> StageCheckpointReader for Arc<T>

Implementors