Enum ThreadPriority
pub enum ThreadPriority {
Min,
Crossplatform(ThreadPriorityValue),
Os(ThreadPriorityOsValue),
Deadline {
runtime: Duration,
deadline: Duration,
period: Duration,
flags: DeadlineFlags,
},
Max,
}tasks only.Expand description
Thread priority enumeration.
Variants
Min
Holds a value representing the minimum possible priority.
Crossplatform(ThreadPriorityValue)
Holds a platform-independent priority value. Usually used when setting a value, for sometimes it is not possible to map the operating system’s priority to this value.
Os(ThreadPriorityOsValue)
Holds an operating system specific value. If it is not possible to obtain the
ThreadPriority::Crossplatform variant of the value, this is returned instead.
Deadline
Holds scheduling parameters for Deadline scheduling. These are, in order, the nanoseconds for runtime, deadline, and period. Please note that the kernel enforces runtime <= deadline <= period.
arrival/wakeup absolute deadline | start time | | | | v v v —–x––––xooooooooooooooooo––––x––––x— |<– Runtime —––>| |<———– Deadline ———–>| |<––––––– Period —————––>|
Fields
runtime: DurationSet this to something larger than the average computation time or to the worst-case computation time for hard real-time tasks.
flags: DeadlineFlagsDeadline flags.
Max
Holds a value representing the maximum possible priority. Should be used with caution, it solely depends on the target os where the program is going to be running on, how it will behave. On some systems, the whole system may become frozen if not used properly.
Implementations
impl ThreadPriority
impl ThreadPriority
pub fn max_value_for_policy(policy: ThreadSchedulePolicy) -> Result<i32, Error>
pub fn max_value_for_policy(policy: ThreadSchedulePolicy) -> Result<i32, Error>
Returns the maximum allowed value for using with the provided policy. The returned number is in the range of allowed values.
pub fn min_value_for_policy(policy: ThreadSchedulePolicy) -> Result<i32, Error>
pub fn min_value_for_policy(policy: ThreadSchedulePolicy) -> Result<i32, Error>
Returns the minimum allowed value for using with the provided policy. The returned number is in the range of allowed values.
pub fn to_allowed_value_for_policy(
priority: i32,
policy: ThreadSchedulePolicy,
) -> Result<i32, Error>
pub fn to_allowed_value_for_policy( priority: i32, policy: ThreadSchedulePolicy, ) -> Result<i32, Error>
Checks that the passed priority value is within the range of allowed values for using with the provided policy.
pub fn to_posix(self, policy: ThreadSchedulePolicy) -> Result<i32, Error>
pub fn to_posix(self, policy: ThreadSchedulePolicy) -> Result<i32, Error>
Converts the priority stored to a posix number. POSIX value can not be known without knowing the scheduling policy https://linux.die.net/man/2/sched_get_priority_max
For threads scheduled under one of the normal scheduling policies (SCHED_OTHER, SCHED_IDLE, SCHED_BATCH), sched_priority is not used in scheduling decisions (it must be specified as 0). Source: https://man7.org/linux/man-pages/man7/sched.7.html Due to this restriction of normal scheduling policies and the intention of the library, the niceness is used instead for such processes.
pub fn from_posix(params: ScheduleParams) -> ThreadPriority
pub fn from_posix(params: ScheduleParams) -> ThreadPriority
Gets priority value from POSIX value. In order to interpret it correctly, you should also take scheduling policy into account.
impl ThreadPriority
impl ThreadPriority
pub fn set_for_current(self) -> Result<(), Error>
pub fn set_for_current(self) -> Result<(), Error>
Sets current thread’s priority to this value.