DatabaseStorageProof

Trait DatabaseStorageProof 

pub trait DatabaseStorageProof<'a, TX> {
    // Required methods
    fn from_tx(tx: &'a TX, address: Address) -> Self;
    fn overlay_storage_proof(
        tx: &'a TX,
        address: Address,
        slot: FixedBytes<32>,
        storage: HashedStorage,
    ) -> Result<StorageProof, StateProofError>;
    fn overlay_storage_multiproof(
        tx: &'a TX,
        address: Address,
        slots: &[FixedBytes<32>],
        storage: HashedStorage,
    ) -> Result<StorageMultiProof, StateProofError>;
}
Available on crate features trie-db and trie only.
Extends StorageProof with operations specific for working with a database transaction.

Required Methods

fn from_tx(tx: &'a TX, address: Address) -> Self

Create a new StorageProof from database transaction and account address.

fn overlay_storage_proof( tx: &'a TX, address: Address, slot: FixedBytes<32>, storage: HashedStorage, ) -> Result<StorageProof, StateProofError>

Generates the storage proof for target slot based on TrieInput.

fn overlay_storage_multiproof( tx: &'a TX, address: Address, slots: &[FixedBytes<32>], storage: HashedStorage, ) -> Result<StorageMultiProof, StateProofError>

Generates the storage multiproof for target slots based on TrieInput.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors