Function MALLOCX_ALIGN
pub const fn MALLOCX_ALIGN(aling: usize) -> i32Available on crate feature
cli only.Expand description
Align the memory allocation to start at an address that is a multiple of align,
where a is a power of two.
Safety
This macro does not validate that a is a power of 2.