pub trait ExecutableTxIterator<Evm>: ExecutableTxTuple{
type Recovered: RecoveredTx<<<Evm as ConfigureEvm>::Primitives as NodePrimitives>::SignedTx> + Send + Sync;
}Available on crate feature
evm only.Expand description
Iterator over executable transactions.
See also ExecutableTxTuple for the raw transaction iterator and converter this extension
trait builds on.
Required Associated Types
Sourcetype Recovered: RecoveredTx<<<Evm as ConfigureEvm>::Primitives as NodePrimitives>::SignedTx> + Send + Sync
type Recovered: RecoveredTx<<<Evm as ConfigureEvm>::Primitives as NodePrimitives>::SignedTx> + Send + Sync
HACK: for some reason, this duplicated AT is the only way to enforce the inner Recovered:
Send + Sync bound. Effectively alias for Self::Tx::Recovered.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".