Function nlimbs
pub const fn nlimbs(bits: usize) -> usizeAvailable on crate feature
evm only.Expand description
Number of u64 limbs required to represent the given number of bits.
This needs to be public because it is used in the Uint type.