Trait TryIntoSimTx
pub trait TryIntoSimTx<T>: Sized {
// Required method
fn try_into_sim_tx(self) -> Result<T, ValueError<Self>>;
}Available on crate feature
node-api only.Expand description
Converts self into T.
Should create a fake transaction for simulation using TransactionRequest.
Required Methods
fn try_into_sim_tx(self) -> Result<T, ValueError<Self>>
fn try_into_sim_tx(self) -> Result<T, ValueError<Self>>
Performs the conversion.
Should return a signed typed transaction envelope for the eth_simulateV1 endpoint with a
dummy signature or an error if required fields are missing.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".