pub fn append_matching_block_logs<P, C>(
all_logs: &mut Vec<<<C as RpcConvert>::Network as RpcTypes>::Log>,
converter: &C,
provider_or_block: ProviderOrBlock<'_, P>,
filter: &Filter,
header: &SealedHeader<<<C as RpcConvert>::Primitives as NodePrimitives>::BlockHeader>,
receipts: &[<P as ReceiptProvider>::Receipt],
removed: bool,
) -> Result<(), EthApiError>where
P: BlockReader,
<P as TransactionsProvider>::Transaction: SignedTransaction,
C: RpcConvert,
<C as RpcConvert>::Primitives: NodePrimitives<Block = <P as BlockReader>::Block, Receipt = <P as ReceiptProvider>::Receipt>,Available on crate feature
rpc only.Expand description
Appends all matching and converted logs of a block’s receipts. If the log matches, look up the corresponding transaction hash.